"""VirtualComponent"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.system_model.part_model import _2738

_VIRTUAL_COMPONENT = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel", "VirtualComponent"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model import _2452
    from mastapy._private.system_model.part_model import (
        _2715,
        _2734,
        _2735,
        _2743,
        _2747,
        _2748,
        _2754,
    )

    Self = TypeVar("Self", bound="VirtualComponent")
    CastSelf = TypeVar("CastSelf", bound="VirtualComponent._Cast_VirtualComponent")


__docformat__ = "restructuredtext en"
__all__ = ("VirtualComponent",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_VirtualComponent:
    """Special nested class for casting VirtualComponent to subclasses."""

    __parent__: "VirtualComponent"

    @property
    def mountable_component(self: "CastSelf") -> "_2738.MountableComponent":
        return self.__parent__._cast(_2738.MountableComponent)

    @property
    def component(self: "CastSelf") -> "_2715.Component":
        from mastapy._private.system_model.part_model import _2715

        return self.__parent__._cast(_2715.Component)

    @property
    def part(self: "CastSelf") -> "_2743.Part":
        from mastapy._private.system_model.part_model import _2743

        return self.__parent__._cast(_2743.Part)

    @property
    def design_entity(self: "CastSelf") -> "_2452.DesignEntity":
        from mastapy._private.system_model import _2452

        return self.__parent__._cast(_2452.DesignEntity)

    @property
    def mass_disc(self: "CastSelf") -> "_2734.MassDisc":
        from mastapy._private.system_model.part_model import _2734

        return self.__parent__._cast(_2734.MassDisc)

    @property
    def measurement_component(self: "CastSelf") -> "_2735.MeasurementComponent":
        from mastapy._private.system_model.part_model import _2735

        return self.__parent__._cast(_2735.MeasurementComponent)

    @property
    def point_load(self: "CastSelf") -> "_2747.PointLoad":
        from mastapy._private.system_model.part_model import _2747

        return self.__parent__._cast(_2747.PointLoad)

    @property
    def power_load(self: "CastSelf") -> "_2748.PowerLoad":
        from mastapy._private.system_model.part_model import _2748

        return self.__parent__._cast(_2748.PowerLoad)

    @property
    def unbalanced_mass(self: "CastSelf") -> "_2754.UnbalancedMass":
        from mastapy._private.system_model.part_model import _2754

        return self.__parent__._cast(_2754.UnbalancedMass)

    @property
    def virtual_component(self: "CastSelf") -> "VirtualComponent":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class VirtualComponent(_2738.MountableComponent):
    """VirtualComponent

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VIRTUAL_COMPONENT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_VirtualComponent":
        """Cast to another type.

        Returns:
            _Cast_VirtualComponent
        """
        return _Cast_VirtualComponent(self)



"""Remoting"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.class_property import classproperty
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import conversion

_REMOTING = python_net_import("SMT.MastaAPIUtility", "Remoting")

if TYPE_CHECKING:
    from typing import Any, Iterable, NoReturn, Type


__docformat__ = "restructuredtext en"
__all__ = ("Remoting",)


class Remoting:
    """Remoting

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _REMOTING

    def __new__(cls: "Type[Remoting]", *args: "Any", **kwargs: "Any") -> "NoReturn":
        """Override of the new magic method.

        Note:
            This class cannot be instantiated and this method will always throw an
            exception.

        Args:
            cls (Type[Remoting]: The class to instantiate.
            *args (Any): Arguments.
            **kwargs (Any): Keyword arguments.

        Returns:
            NoReturn
        """
        raise TypeError("Class cannot be instantiated. Please use statically.")

    @classproperty
    @exception_bridge
    def masta_processes(cls) -> "Iterable[int]":
        """Iterable[int]"""
        temp = pythonnet_property_get(Remoting.TYPE, "MastaProcesses")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_iterable(temp, int)

        if value is None:
            return None

        return value

    @classproperty
    @exception_bridge
    def remote_identifier(cls) -> "str":
        """str"""
        temp = pythonnet_property_get(Remoting.TYPE, "RemoteIdentifier")

        if temp is None:
            return ""

        return temp

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def initialise(process_id: "int") -> None:
        """Method does not return.

        Args:
            process_id (int)
        """
        process_id = int(process_id)
        pythonnet_method_call(
            Remoting.TYPE, "Initialise", process_id if process_id else 0
        )

    @staticmethod
    @exception_bridge
    def stop() -> None:
        """Method does not return."""
        pythonnet_method_call(Remoting.TYPE, "Stop")

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def url_for_process_id(process_id: "int") -> "str":
        """str

        Args:
            process_id (int)
        """
        process_id = int(process_id)
        method_result = pythonnet_method_call(
            Remoting.TYPE, "UrlForProcessId", process_id if process_id else 0
        )
        return method_result

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def is_remoting(process_id: "int" = 0) -> "bool":
        """bool

        Args:
            process_id (int, optional)
        """
        process_id = int(process_id)
        method_result = pythonnet_method_call(
            Remoting.TYPE, "IsRemoting", process_id if process_id else 0
        )
        return method_result

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def is_masta_or_runna_process(process_id: "int") -> "bool":
        """bool

        Args:
            process_id (int)
        """
        process_id = int(process_id)
        method_result = pythonnet_method_call(
            Remoting.TYPE, "IsMastaOrRunnaProcess", process_id if process_id else 0
        )
        return method_result

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def remoting_port_name(process_id: "int") -> "str":
        """str

        Args:
            process_id (int)
        """
        process_id = int(process_id)
        method_result = pythonnet_method_call(
            Remoting.TYPE, "RemotingPortName", process_id if process_id else 0
        )
        return method_result

    @staticmethod
    @exception_bridge
    def remoting_port_name_for_current_process() -> "str":
        """str"""
        method_result = pythonnet_method_call(
            Remoting.TYPE, "RemotingPortNameForCurrentProcess"
        )
        return method_result



"""PartSteadyStateSynchronousResponse"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7946

_PART_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses",
    "PartSteadyStateSynchronousResponse",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7943
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
        _3281,
        _3282,
        _3283,
        _3286,
        _3287,
        _3288,
        _3289,
        _3291,
        _3293,
        _3294,
        _3295,
        _3296,
        _3298,
        _3299,
        _3300,
        _3301,
        _3303,
        _3304,
        _3306,
        _3308,
        _3309,
        _3311,
        _3312,
        _3314,
        _3315,
        _3317,
        _3319,
        _3320,
        _3322,
        _3323,
        _3324,
        _3327,
        _3329,
        _3330,
        _3331,
        _3332,
        _3334,
        _3336,
        _3337,
        _3338,
        _3339,
        _3341,
        _3342,
        _3343,
        _3345,
        _3346,
        _3349,
        _3350,
        _3352,
        _3353,
        _3355,
        _3356,
        _3357,
        _3358,
        _3359,
        _3360,
        _3361,
        _3362,
        _3365,
        _3366,
        _3368,
        _3369,
        _3370,
        _3371,
        _3372,
        _3373,
        _3375,
        _3377,
        _3378,
        _3379,
        _3380,
        _3382,
        _3384,
        _3385,
        _3387,
        _3388,
        _3389,
        _3393,
        _3394,
        _3396,
        _3397,
        _3398,
        _3399,
        _3400,
        _3401,
        _3402,
        _3403,
        _3405,
        _3406,
        _3407,
        _3408,
        _3409,
        _3411,
        _3412,
        _3414,
        _3415,
    )
    from mastapy._private.system_model.part_model import _2743

    Self = TypeVar("Self", bound="PartSteadyStateSynchronousResponse")
    CastSelf = TypeVar(
        "CastSelf",
        bound="PartSteadyStateSynchronousResponse._Cast_PartSteadyStateSynchronousResponse",
    )


__docformat__ = "restructuredtext en"
__all__ = ("PartSteadyStateSynchronousResponse",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PartSteadyStateSynchronousResponse:
    """Special nested class for casting PartSteadyStateSynchronousResponse to subclasses."""

    __parent__: "PartSteadyStateSynchronousResponse"

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def abstract_assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3281.AbstractAssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3281,
        )

        return self.__parent__._cast(
            _3281.AbstractAssemblySteadyStateSynchronousResponse
        )

    @property
    def abstract_shaft_or_housing_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3282.AbstractShaftOrHousingSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3282,
        )

        return self.__parent__._cast(
            _3282.AbstractShaftOrHousingSteadyStateSynchronousResponse
        )

    @property
    def abstract_shaft_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3283.AbstractShaftSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3283,
        )

        return self.__parent__._cast(_3283.AbstractShaftSteadyStateSynchronousResponse)

    @property
    def agma_gleason_conical_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3286.AGMAGleasonConicalGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3286,
        )

        return self.__parent__._cast(
            _3286.AGMAGleasonConicalGearSetSteadyStateSynchronousResponse
        )

    @property
    def agma_gleason_conical_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3287.AGMAGleasonConicalGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3287,
        )

        return self.__parent__._cast(
            _3287.AGMAGleasonConicalGearSteadyStateSynchronousResponse
        )

    @property
    def assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3288.AssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3288,
        )

        return self.__parent__._cast(_3288.AssemblySteadyStateSynchronousResponse)

    @property
    def bearing_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3289.BearingSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3289,
        )

        return self.__parent__._cast(_3289.BearingSteadyStateSynchronousResponse)

    @property
    def belt_drive_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3291.BeltDriveSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3291,
        )

        return self.__parent__._cast(_3291.BeltDriveSteadyStateSynchronousResponse)

    @property
    def bevel_differential_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3293.BevelDifferentialGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3293,
        )

        return self.__parent__._cast(
            _3293.BevelDifferentialGearSetSteadyStateSynchronousResponse
        )

    @property
    def bevel_differential_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3294.BevelDifferentialGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3294,
        )

        return self.__parent__._cast(
            _3294.BevelDifferentialGearSteadyStateSynchronousResponse
        )

    @property
    def bevel_differential_planet_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3295.BevelDifferentialPlanetGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3295,
        )

        return self.__parent__._cast(
            _3295.BevelDifferentialPlanetGearSteadyStateSynchronousResponse
        )

    @property
    def bevel_differential_sun_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3296.BevelDifferentialSunGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3296,
        )

        return self.__parent__._cast(
            _3296.BevelDifferentialSunGearSteadyStateSynchronousResponse
        )

    @property
    def bevel_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3298.BevelGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3298,
        )

        return self.__parent__._cast(_3298.BevelGearSetSteadyStateSynchronousResponse)

    @property
    def bevel_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3299.BevelGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3299,
        )

        return self.__parent__._cast(_3299.BevelGearSteadyStateSynchronousResponse)

    @property
    def bolted_joint_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3300.BoltedJointSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3300,
        )

        return self.__parent__._cast(_3300.BoltedJointSteadyStateSynchronousResponse)

    @property
    def bolt_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3301.BoltSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3301,
        )

        return self.__parent__._cast(_3301.BoltSteadyStateSynchronousResponse)

    @property
    def clutch_half_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3303.ClutchHalfSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3303,
        )

        return self.__parent__._cast(_3303.ClutchHalfSteadyStateSynchronousResponse)

    @property
    def clutch_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3304.ClutchSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3304,
        )

        return self.__parent__._cast(_3304.ClutchSteadyStateSynchronousResponse)

    @property
    def component_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3306.ComponentSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3306,
        )

        return self.__parent__._cast(_3306.ComponentSteadyStateSynchronousResponse)

    @property
    def concept_coupling_half_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3308.ConceptCouplingHalfSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3308,
        )

        return self.__parent__._cast(
            _3308.ConceptCouplingHalfSteadyStateSynchronousResponse
        )

    @property
    def concept_coupling_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3309.ConceptCouplingSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3309,
        )

        return self.__parent__._cast(
            _3309.ConceptCouplingSteadyStateSynchronousResponse
        )

    @property
    def concept_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3311.ConceptGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3311,
        )

        return self.__parent__._cast(_3311.ConceptGearSetSteadyStateSynchronousResponse)

    @property
    def concept_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3312.ConceptGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3312,
        )

        return self.__parent__._cast(_3312.ConceptGearSteadyStateSynchronousResponse)

    @property
    def conical_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3314.ConicalGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3314,
        )

        return self.__parent__._cast(_3314.ConicalGearSetSteadyStateSynchronousResponse)

    @property
    def conical_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3315.ConicalGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3315,
        )

        return self.__parent__._cast(_3315.ConicalGearSteadyStateSynchronousResponse)

    @property
    def connector_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3317.ConnectorSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3317,
        )

        return self.__parent__._cast(_3317.ConnectorSteadyStateSynchronousResponse)

    @property
    def coupling_half_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3319.CouplingHalfSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3319,
        )

        return self.__parent__._cast(_3319.CouplingHalfSteadyStateSynchronousResponse)

    @property
    def coupling_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3320.CouplingSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3320,
        )

        return self.__parent__._cast(_3320.CouplingSteadyStateSynchronousResponse)

    @property
    def cvt_pulley_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3322.CVTPulleySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3322,
        )

        return self.__parent__._cast(_3322.CVTPulleySteadyStateSynchronousResponse)

    @property
    def cvt_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3323.CVTSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3323,
        )

        return self.__parent__._cast(_3323.CVTSteadyStateSynchronousResponse)

    @property
    def cycloidal_assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3324.CycloidalAssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3324,
        )

        return self.__parent__._cast(
            _3324.CycloidalAssemblySteadyStateSynchronousResponse
        )

    @property
    def cycloidal_disc_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3327.CycloidalDiscSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3327,
        )

        return self.__parent__._cast(_3327.CycloidalDiscSteadyStateSynchronousResponse)

    @property
    def cylindrical_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3329.CylindricalGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3329,
        )

        return self.__parent__._cast(
            _3329.CylindricalGearSetSteadyStateSynchronousResponse
        )

    @property
    def cylindrical_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3330.CylindricalGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3330,
        )

        return self.__parent__._cast(
            _3330.CylindricalGearSteadyStateSynchronousResponse
        )

    @property
    def cylindrical_planet_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3331.CylindricalPlanetGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3331,
        )

        return self.__parent__._cast(
            _3331.CylindricalPlanetGearSteadyStateSynchronousResponse
        )

    @property
    def datum_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3332.DatumSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3332,
        )

        return self.__parent__._cast(_3332.DatumSteadyStateSynchronousResponse)

    @property
    def external_cad_model_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3334.ExternalCADModelSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3334,
        )

        return self.__parent__._cast(
            _3334.ExternalCADModelSteadyStateSynchronousResponse
        )

    @property
    def face_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3336.FaceGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3336,
        )

        return self.__parent__._cast(_3336.FaceGearSetSteadyStateSynchronousResponse)

    @property
    def face_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3337.FaceGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3337,
        )

        return self.__parent__._cast(_3337.FaceGearSteadyStateSynchronousResponse)

    @property
    def fe_part_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3338.FEPartSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3338,
        )

        return self.__parent__._cast(_3338.FEPartSteadyStateSynchronousResponse)

    @property
    def flexible_pin_assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3339.FlexiblePinAssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3339,
        )

        return self.__parent__._cast(
            _3339.FlexiblePinAssemblySteadyStateSynchronousResponse
        )

    @property
    def gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3341.GearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3341,
        )

        return self.__parent__._cast(_3341.GearSetSteadyStateSynchronousResponse)

    @property
    def gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3342.GearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3342,
        )

        return self.__parent__._cast(_3342.GearSteadyStateSynchronousResponse)

    @property
    def guide_dxf_model_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3343.GuideDxfModelSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3343,
        )

        return self.__parent__._cast(_3343.GuideDxfModelSteadyStateSynchronousResponse)

    @property
    def hypoid_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3345.HypoidGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3345,
        )

        return self.__parent__._cast(_3345.HypoidGearSetSteadyStateSynchronousResponse)

    @property
    def hypoid_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3346.HypoidGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3346,
        )

        return self.__parent__._cast(_3346.HypoidGearSteadyStateSynchronousResponse)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3349.KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3349,
        )

        return self.__parent__._cast(
            _3349.KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3350.KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3350,
        )

        return self.__parent__._cast(
            _3350.KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3352.KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3352,
        )

        return self.__parent__._cast(
            _3352.KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3353.KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3353,
        )

        return self.__parent__._cast(
            _3353.KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> (
        "_3355.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponse"
    ):
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3355,
        )

        return self.__parent__._cast(
            _3355.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3356.KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3356,
        )

        return self.__parent__._cast(
            _3356.KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponse
        )

    @property
    def mass_disc_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3357.MassDiscSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3357,
        )

        return self.__parent__._cast(_3357.MassDiscSteadyStateSynchronousResponse)

    @property
    def measurement_component_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3358.MeasurementComponentSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3358,
        )

        return self.__parent__._cast(
            _3358.MeasurementComponentSteadyStateSynchronousResponse
        )

    @property
    def microphone_array_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3359.MicrophoneArraySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3359,
        )

        return self.__parent__._cast(
            _3359.MicrophoneArraySteadyStateSynchronousResponse
        )

    @property
    def microphone_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3360.MicrophoneSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3360,
        )

        return self.__parent__._cast(_3360.MicrophoneSteadyStateSynchronousResponse)

    @property
    def mountable_component_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3361.MountableComponentSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3361,
        )

        return self.__parent__._cast(
            _3361.MountableComponentSteadyStateSynchronousResponse
        )

    @property
    def oil_seal_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3362.OilSealSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3362,
        )

        return self.__parent__._cast(_3362.OilSealSteadyStateSynchronousResponse)

    @property
    def part_to_part_shear_coupling_half_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3365.PartToPartShearCouplingHalfSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3365,
        )

        return self.__parent__._cast(
            _3365.PartToPartShearCouplingHalfSteadyStateSynchronousResponse
        )

    @property
    def part_to_part_shear_coupling_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3366.PartToPartShearCouplingSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3366,
        )

        return self.__parent__._cast(
            _3366.PartToPartShearCouplingSteadyStateSynchronousResponse
        )

    @property
    def planetary_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3368.PlanetaryGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3368,
        )

        return self.__parent__._cast(
            _3368.PlanetaryGearSetSteadyStateSynchronousResponse
        )

    @property
    def planet_carrier_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3369.PlanetCarrierSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3369,
        )

        return self.__parent__._cast(_3369.PlanetCarrierSteadyStateSynchronousResponse)

    @property
    def point_load_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3370.PointLoadSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3370,
        )

        return self.__parent__._cast(_3370.PointLoadSteadyStateSynchronousResponse)

    @property
    def power_load_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3371.PowerLoadSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3371,
        )

        return self.__parent__._cast(_3371.PowerLoadSteadyStateSynchronousResponse)

    @property
    def pulley_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3372.PulleySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3372,
        )

        return self.__parent__._cast(_3372.PulleySteadyStateSynchronousResponse)

    @property
    def ring_pins_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3373.RingPinsSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3373,
        )

        return self.__parent__._cast(_3373.RingPinsSteadyStateSynchronousResponse)

    @property
    def rolling_ring_assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3375.RollingRingAssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3375,
        )

        return self.__parent__._cast(
            _3375.RollingRingAssemblySteadyStateSynchronousResponse
        )

    @property
    def rolling_ring_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3377.RollingRingSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3377,
        )

        return self.__parent__._cast(_3377.RollingRingSteadyStateSynchronousResponse)

    @property
    def root_assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3378.RootAssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3378,
        )

        return self.__parent__._cast(_3378.RootAssemblySteadyStateSynchronousResponse)

    @property
    def shaft_hub_connection_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3379.ShaftHubConnectionSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3379,
        )

        return self.__parent__._cast(
            _3379.ShaftHubConnectionSteadyStateSynchronousResponse
        )

    @property
    def shaft_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3380.ShaftSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3380,
        )

        return self.__parent__._cast(_3380.ShaftSteadyStateSynchronousResponse)

    @property
    def specialised_assembly_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3382.SpecialisedAssemblySteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3382,
        )

        return self.__parent__._cast(
            _3382.SpecialisedAssemblySteadyStateSynchronousResponse
        )

    @property
    def spiral_bevel_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3384.SpiralBevelGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3384,
        )

        return self.__parent__._cast(
            _3384.SpiralBevelGearSetSteadyStateSynchronousResponse
        )

    @property
    def spiral_bevel_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3385.SpiralBevelGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3385,
        )

        return self.__parent__._cast(
            _3385.SpiralBevelGearSteadyStateSynchronousResponse
        )

    @property
    def spring_damper_half_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3387.SpringDamperHalfSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3387,
        )

        return self.__parent__._cast(
            _3387.SpringDamperHalfSteadyStateSynchronousResponse
        )

    @property
    def spring_damper_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3388.SpringDamperSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3388,
        )

        return self.__parent__._cast(_3388.SpringDamperSteadyStateSynchronousResponse)

    @property
    def straight_bevel_diff_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3393.StraightBevelDiffGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3393,
        )

        return self.__parent__._cast(
            _3393.StraightBevelDiffGearSetSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_diff_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3394.StraightBevelDiffGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3394,
        )

        return self.__parent__._cast(
            _3394.StraightBevelDiffGearSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3396.StraightBevelGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3396,
        )

        return self.__parent__._cast(
            _3396.StraightBevelGearSetSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3397.StraightBevelGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3397,
        )

        return self.__parent__._cast(
            _3397.StraightBevelGearSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_planet_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3398.StraightBevelPlanetGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3398,
        )

        return self.__parent__._cast(
            _3398.StraightBevelPlanetGearSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_sun_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3399.StraightBevelSunGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3399,
        )

        return self.__parent__._cast(
            _3399.StraightBevelSunGearSteadyStateSynchronousResponse
        )

    @property
    def synchroniser_half_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3400.SynchroniserHalfSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3400,
        )

        return self.__parent__._cast(
            _3400.SynchroniserHalfSteadyStateSynchronousResponse
        )

    @property
    def synchroniser_part_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3401.SynchroniserPartSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3401,
        )

        return self.__parent__._cast(
            _3401.SynchroniserPartSteadyStateSynchronousResponse
        )

    @property
    def synchroniser_sleeve_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3402.SynchroniserSleeveSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3402,
        )

        return self.__parent__._cast(
            _3402.SynchroniserSleeveSteadyStateSynchronousResponse
        )

    @property
    def synchroniser_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3403.SynchroniserSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3403,
        )

        return self.__parent__._cast(_3403.SynchroniserSteadyStateSynchronousResponse)

    @property
    def torque_converter_pump_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3405.TorqueConverterPumpSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3405,
        )

        return self.__parent__._cast(
            _3405.TorqueConverterPumpSteadyStateSynchronousResponse
        )

    @property
    def torque_converter_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3406.TorqueConverterSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3406,
        )

        return self.__parent__._cast(
            _3406.TorqueConverterSteadyStateSynchronousResponse
        )

    @property
    def torque_converter_turbine_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3407.TorqueConverterTurbineSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3407,
        )

        return self.__parent__._cast(
            _3407.TorqueConverterTurbineSteadyStateSynchronousResponse
        )

    @property
    def unbalanced_mass_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3408.UnbalancedMassSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3408,
        )

        return self.__parent__._cast(_3408.UnbalancedMassSteadyStateSynchronousResponse)

    @property
    def virtual_component_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3409.VirtualComponentSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3409,
        )

        return self.__parent__._cast(
            _3409.VirtualComponentSteadyStateSynchronousResponse
        )

    @property
    def worm_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3411.WormGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3411,
        )

        return self.__parent__._cast(_3411.WormGearSetSteadyStateSynchronousResponse)

    @property
    def worm_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3412.WormGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3412,
        )

        return self.__parent__._cast(_3412.WormGearSteadyStateSynchronousResponse)

    @property
    def zerol_bevel_gear_set_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3414.ZerolBevelGearSetSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3414,
        )

        return self.__parent__._cast(
            _3414.ZerolBevelGearSetSteadyStateSynchronousResponse
        )

    @property
    def zerol_bevel_gear_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3415.ZerolBevelGearSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3415,
        )

        return self.__parent__._cast(_3415.ZerolBevelGearSteadyStateSynchronousResponse)

    @property
    def part_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "PartSteadyStateSynchronousResponse":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PartSteadyStateSynchronousResponse(_7946.PartStaticLoadAnalysisCase):
    """PartSteadyStateSynchronousResponse

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PART_STEADY_STATE_SYNCHRONOUS_RESPONSE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2743.Part":
        """mastapy.system_model.part_model.Part

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def steady_state_synchronous_response(
        self: "Self",
    ) -> "_3389.SteadyStateSynchronousResponse":
        """mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.SteadyStateSynchronousResponse

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SteadyStateSynchronousResponse")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_PartSteadyStateSynchronousResponse":
        """Cast to another type.

        Returns:
            _Cast_PartSteadyStateSynchronousResponse
        """
        return _Cast_PartSteadyStateSynchronousResponse(self)



"""CylindricalPlanetaryGearSetDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, utility
from mastapy._private.gears.gear_designs.cylindrical import _1160

_CYLINDRICAL_PLANETARY_GEAR_SET_DESIGN = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "CylindricalPlanetaryGearSetDesign"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs import _1074, _1076
    from mastapy._private.math_utility import _1726
    from mastapy._private.utility_gui.charts import _2106

    Self = TypeVar("Self", bound="CylindricalPlanetaryGearSetDesign")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalPlanetaryGearSetDesign._Cast_CylindricalPlanetaryGearSetDesign",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalPlanetaryGearSetDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalPlanetaryGearSetDesign:
    """Special nested class for casting CylindricalPlanetaryGearSetDesign to subclasses."""

    __parent__: "CylindricalPlanetaryGearSetDesign"

    @property
    def cylindrical_gear_set_design(
        self: "CastSelf",
    ) -> "_1160.CylindricalGearSetDesign":
        return self.__parent__._cast(_1160.CylindricalGearSetDesign)

    @property
    def gear_set_design(self: "CastSelf") -> "_1076.GearSetDesign":
        from mastapy._private.gears.gear_designs import _1076

        return self.__parent__._cast(_1076.GearSetDesign)

    @property
    def gear_design_component(self: "CastSelf") -> "_1074.GearDesignComponent":
        from mastapy._private.gears.gear_designs import _1074

        return self.__parent__._cast(_1074.GearDesignComponent)

    @property
    def cylindrical_planetary_gear_set_design(
        self: "CastSelf",
    ) -> "CylindricalPlanetaryGearSetDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalPlanetaryGearSetDesign(_1160.CylindricalGearSetDesign):
    """CylindricalPlanetaryGearSetDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_PLANETARY_GEAR_SET_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def equally_spaced_planets_are_assemblable(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "EquallySpacedPlanetsAreAssemblable"
        )

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def in_phase(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InPhase")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def least_mesh_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeastMeshAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normal_module_scale_planet_diameters(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "NormalModuleScalePlanetDiameters")

        if temp is None:
            return 0.0

        return temp

    @normal_module_scale_planet_diameters.setter
    @exception_bridge
    @enforce_parameter_types
    def normal_module_scale_planet_diameters(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NormalModuleScalePlanetDiameters",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def planet_gear_phasing_chart(self: "Self") -> "_2106.TwoDChartDefinition":
        """mastapy.utility_gui.charts.TwoDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PlanetGearPhasingChart")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def reference_fixed_gear_for_planetary_sideband_fourier_series_is_annulus(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "ReferenceFixedGearForPlanetarySidebandFourierSeriesIsAnnulus"
        )

        if temp is None:
            return False

        return temp

    @reference_fixed_gear_for_planetary_sideband_fourier_series_is_annulus.setter
    @exception_bridge
    @enforce_parameter_types
    def reference_fixed_gear_for_planetary_sideband_fourier_series_is_annulus(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "ReferenceFixedGearForPlanetarySidebandFourierSeriesIsAnnulus",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_planet_passing_window_function_in_planetary_sideband_fourier_series(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped,
            "UsePlanetPassingWindowFunctionInPlanetarySidebandFourierSeries",
        )

        if temp is None:
            return False

        return temp

    @use_planet_passing_window_function_in_planetary_sideband_fourier_series.setter
    @exception_bridge
    @enforce_parameter_types
    def use_planet_passing_window_function_in_planetary_sideband_fourier_series(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "UsePlanetPassingWindowFunctionInPlanetarySidebandFourierSeries",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def planetary_sideband_fourier_series_for_rotating_planet_carrier(
        self: "Self",
    ) -> "_1726.FourierSeries":
        """mastapy.math_utility.FourierSeries

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "PlanetarySidebandFourierSeriesForRotatingPlanetCarrier"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    def add_new_micro_geometry_using_planetary_duplicates(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(
            self.wrapped, "AddNewMicroGeometryUsingPlanetaryDuplicates"
        )

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalPlanetaryGearSetDesign":
        """Cast to another type.

        Returns:
            _Cast_CylindricalPlanetaryGearSetDesign
        """
        return _Cast_CylindricalPlanetaryGearSetDesign(self)



"""BearingNodeOption"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_BEARING_NODE_OPTION = python_net_import(
    "SMT.MastaAPI.SystemModel.FE", "BearingNodeOption"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="BearingNodeOption")
    CastSelf = TypeVar("CastSelf", bound="BearingNodeOption._Cast_BearingNodeOption")


__docformat__ = "restructuredtext en"
__all__ = ("BearingNodeOption",)


class BearingNodeOption(Enum):
    """BearingNodeOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _BEARING_NODE_OPTION

    SINGLE_NODE_FOR_BEARING = 0
    NODE_PER_BEARING_ROW = 1


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


BearingNodeOption.__setattr__ = __enum_setattr
BearingNodeOption.__delattr__ = __enum_delattr



"""ConicalGearLoadCase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.static_loads import _7813

_CONICAL_GEAR_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "ConicalGearLoadCase"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7736,
        _7745,
        _7748,
        _7749,
        _7750,
        _7760,
        _7768,
        _7828,
        _7835,
        _7838,
        _7841,
        _7849,
        _7853,
        _7880,
        _7886,
        _7889,
        _7892,
        _7893,
        _7913,
    )
    from mastapy._private.system_model.part_model.gears import _2805

    Self = TypeVar("Self", bound="ConicalGearLoadCase")
    CastSelf = TypeVar(
        "CastSelf", bound="ConicalGearLoadCase._Cast_ConicalGearLoadCase"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalGearLoadCase:
    """Special nested class for casting ConicalGearLoadCase to subclasses."""

    __parent__: "ConicalGearLoadCase"

    @property
    def gear_load_case(self: "CastSelf") -> "_7813.GearLoadCase":
        return self.__parent__._cast(_7813.GearLoadCase)

    @property
    def mountable_component_load_case(
        self: "CastSelf",
    ) -> "_7849.MountableComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7849,
        )

        return self.__parent__._cast(_7849.MountableComponentLoadCase)

    @property
    def component_load_case(self: "CastSelf") -> "_7760.ComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7760,
        )

        return self.__parent__._cast(_7760.ComponentLoadCase)

    @property
    def part_load_case(self: "CastSelf") -> "_7853.PartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7853,
        )

        return self.__parent__._cast(_7853.PartLoadCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_7736.AGMAGleasonConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7736,
        )

        return self.__parent__._cast(_7736.AGMAGleasonConicalGearLoadCase)

    @property
    def bevel_differential_gear_load_case(
        self: "CastSelf",
    ) -> "_7745.BevelDifferentialGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7745,
        )

        return self.__parent__._cast(_7745.BevelDifferentialGearLoadCase)

    @property
    def bevel_differential_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7748.BevelDifferentialPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7748,
        )

        return self.__parent__._cast(_7748.BevelDifferentialPlanetGearLoadCase)

    @property
    def bevel_differential_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_7749.BevelDifferentialSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7749,
        )

        return self.__parent__._cast(_7749.BevelDifferentialSunGearLoadCase)

    @property
    def bevel_gear_load_case(self: "CastSelf") -> "_7750.BevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7750,
        )

        return self.__parent__._cast(_7750.BevelGearLoadCase)

    @property
    def hypoid_gear_load_case(self: "CastSelf") -> "_7828.HypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7828,
        )

        return self.__parent__._cast(_7828.HypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_7835.KlingelnbergCycloPalloidConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7835,
        )

        return self.__parent__._cast(_7835.KlingelnbergCycloPalloidConicalGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_load_case(
        self: "CastSelf",
    ) -> "_7838.KlingelnbergCycloPalloidHypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7838,
        )

        return self.__parent__._cast(_7838.KlingelnbergCycloPalloidHypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7841.KlingelnbergCycloPalloidSpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7841,
        )

        return self.__parent__._cast(
            _7841.KlingelnbergCycloPalloidSpiralBevelGearLoadCase
        )

    @property
    def spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7880.SpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7880,
        )

        return self.__parent__._cast(_7880.SpiralBevelGearLoadCase)

    @property
    def straight_bevel_diff_gear_load_case(
        self: "CastSelf",
    ) -> "_7886.StraightBevelDiffGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7886,
        )

        return self.__parent__._cast(_7886.StraightBevelDiffGearLoadCase)

    @property
    def straight_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7889.StraightBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7889,
        )

        return self.__parent__._cast(_7889.StraightBevelGearLoadCase)

    @property
    def straight_bevel_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7892.StraightBevelPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7892,
        )

        return self.__parent__._cast(_7892.StraightBevelPlanetGearLoadCase)

    @property
    def straight_bevel_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_7893.StraightBevelSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7893,
        )

        return self.__parent__._cast(_7893.StraightBevelSunGearLoadCase)

    @property
    def zerol_bevel_gear_load_case(self: "CastSelf") -> "_7913.ZerolBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7913,
        )

        return self.__parent__._cast(_7913.ZerolBevelGearLoadCase)

    @property
    def conical_gear_load_case(self: "CastSelf") -> "ConicalGearLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConicalGearLoadCase(_7813.GearLoadCase):
    """ConicalGearLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_GEAR_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2805.ConicalGear":
        """mastapy.system_model.part_model.gears.ConicalGear

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_manufacture_errors(self: "Self") -> "_7768.ConicalGearManufactureError":
        """mastapy.system_model.analyses_and_results.static_loads.ConicalGearManufactureError

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearManufactureErrors")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def planetaries(self: "Self") -> "List[ConicalGearLoadCase]":
        """List[mastapy.system_model.analyses_and_results.static_loads.ConicalGearLoadCase]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Planetaries")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalGearLoadCase":
        """Cast to another type.

        Returns:
            _Cast_ConicalGearLoadCase
        """
        return _Cast_ConicalGearLoadCase(self)



"""CylindricalGearRatingMethods"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_RATING_METHODS = python_net_import(
    "SMT.MastaAPI.Materials", "CylindricalGearRatingMethods"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="CylindricalGearRatingMethods")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearRatingMethods._Cast_CylindricalGearRatingMethods",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearRatingMethods",)


class CylindricalGearRatingMethods(Enum):
    """CylindricalGearRatingMethods

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _CYLINDRICAL_GEAR_RATING_METHODS

    STANDARD_WITHDRAWN = 0
    AGMA_2101D04 = 1
    ISO_63362019 = 2
    ISO_63362006 = 3
    ISO_63361996 = 4
    DIN_39901987 = 5


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


CylindricalGearRatingMethods.__setattr__ = __enum_setattr
CylindricalGearRatingMethods.__delattr__ = __enum_delattr



"""PerMachineSettings"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
)

from mastapy._private._internal import utility
from mastapy._private.utility import _1821

_PER_MACHINE_SETTINGS = python_net_import("SMT.MastaAPI.Utility", "PerMachineSettings")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings import _2137
    from mastapy._private.gears.gear_designs.cylindrical import _1143
    from mastapy._private.gears.materials import _712
    from mastapy._private.nodal_analysis import _71
    from mastapy._private.nodal_analysis.geometry_modeller_link import _245
    from mastapy._private.system_model.part_model import _2720, _2746
    from mastapy._private.utility import _1822
    from mastapy._private.utility.cad_export import _2069
    from mastapy._private.utility.databases import _2061
    from mastapy._private.utility.scripting import _1968
    from mastapy._private.utility.units_and_measurements import _1832

    Self = TypeVar("Self", bound="PerMachineSettings")
    CastSelf = TypeVar("CastSelf", bound="PerMachineSettings._Cast_PerMachineSettings")


__docformat__ = "restructuredtext en"
__all__ = ("PerMachineSettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PerMachineSettings:
    """Special nested class for casting PerMachineSettings to subclasses."""

    __parent__: "PerMachineSettings"

    @property
    def persistent_singleton(self: "CastSelf") -> "_1821.PersistentSingleton":
        return self.__parent__._cast(_1821.PersistentSingleton)

    @property
    def fe_user_settings(self: "CastSelf") -> "_71.FEUserSettings":
        from mastapy._private.nodal_analysis import _71

        return self.__parent__._cast(_71.FEUserSettings)

    @property
    def geometry_modeller_settings(self: "CastSelf") -> "_245.GeometryModellerSettings":
        from mastapy._private.nodal_analysis.geometry_modeller_link import _245

        return self.__parent__._cast(_245.GeometryModellerSettings)

    @property
    def gear_material_expert_system_factor_settings(
        self: "CastSelf",
    ) -> "_712.GearMaterialExpertSystemFactorSettings":
        from mastapy._private.gears.materials import _712

        return self.__parent__._cast(_712.GearMaterialExpertSystemFactorSettings)

    @property
    def cylindrical_gear_defaults(self: "CastSelf") -> "_1143.CylindricalGearDefaults":
        from mastapy._private.gears.gear_designs.cylindrical import _1143

        return self.__parent__._cast(_1143.CylindricalGearDefaults)

    @property
    def program_settings(self: "CastSelf") -> "_1822.ProgramSettings":
        from mastapy._private.utility import _1822

        return self.__parent__._cast(_1822.ProgramSettings)

    @property
    def measurement_settings(self: "CastSelf") -> "_1832.MeasurementSettings":
        from mastapy._private.utility.units_and_measurements import _1832

        return self.__parent__._cast(_1832.MeasurementSettings)

    @property
    def scripting_setup(self: "CastSelf") -> "_1968.ScriptingSetup":
        from mastapy._private.utility.scripting import _1968

        return self.__parent__._cast(_1968.ScriptingSetup)

    @property
    def database_settings(self: "CastSelf") -> "_2061.DatabaseSettings":
        from mastapy._private.utility.databases import _2061

        return self.__parent__._cast(_2061.DatabaseSettings)

    @property
    def cad_export_settings(self: "CastSelf") -> "_2069.CADExportSettings":
        from mastapy._private.utility.cad_export import _2069

        return self.__parent__._cast(_2069.CADExportSettings)

    @property
    def skf_settings(self: "CastSelf") -> "_2137.SKFSettings":
        from mastapy._private.bearings import _2137

        return self.__parent__._cast(_2137.SKFSettings)

    @property
    def default_export_settings(self: "CastSelf") -> "_2720.DefaultExportSettings":
        from mastapy._private.system_model.part_model import _2720

        return self.__parent__._cast(_2720.DefaultExportSettings)

    @property
    def planet_carrier_settings(self: "CastSelf") -> "_2746.PlanetCarrierSettings":
        from mastapy._private.system_model.part_model import _2746

        return self.__parent__._cast(_2746.PlanetCarrierSettings)

    @property
    def per_machine_settings(self: "CastSelf") -> "PerMachineSettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PerMachineSettings(_1821.PersistentSingleton):
    """PerMachineSettings

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PER_MACHINE_SETTINGS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @exception_bridge
    def reset_to_defaults(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "ResetToDefaults")

    @property
    def cast_to(self: "Self") -> "_Cast_PerMachineSettings":
        """Cast to another type.

        Returns:
            _Cast_PerMachineSettings
        """
        return _Cast_PerMachineSettings(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.rating.cylindrical.optimisation._614 import (
        CylindricalGearSetRatingOptimisationHelper,
    )
    from mastapy._private.gears.rating.cylindrical.optimisation._615 import (
        OptimisationResultsPair,
    )
    from mastapy._private.gears.rating.cylindrical.optimisation._616 import (
        SafetyFactorOptimisationResults,
    )
    from mastapy._private.gears.rating.cylindrical.optimisation._617 import (
        SafetyFactorOptimisationStepResult,
    )
    from mastapy._private.gears.rating.cylindrical.optimisation._618 import (
        SafetyFactorOptimisationStepResultAngle,
    )
    from mastapy._private.gears.rating.cylindrical.optimisation._619 import (
        SafetyFactorOptimisationStepResultNumber,
    )
    from mastapy._private.gears.rating.cylindrical.optimisation._620 import (
        SafetyFactorOptimisationStepResultShortLength,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.rating.cylindrical.optimisation._614": [
            "CylindricalGearSetRatingOptimisationHelper"
        ],
        "_private.gears.rating.cylindrical.optimisation._615": [
            "OptimisationResultsPair"
        ],
        "_private.gears.rating.cylindrical.optimisation._616": [
            "SafetyFactorOptimisationResults"
        ],
        "_private.gears.rating.cylindrical.optimisation._617": [
            "SafetyFactorOptimisationStepResult"
        ],
        "_private.gears.rating.cylindrical.optimisation._618": [
            "SafetyFactorOptimisationStepResultAngle"
        ],
        "_private.gears.rating.cylindrical.optimisation._619": [
            "SafetyFactorOptimisationStepResultNumber"
        ],
        "_private.gears.rating.cylindrical.optimisation._620": [
            "SafetyFactorOptimisationStepResultShortLength"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CylindricalGearSetRatingOptimisationHelper",
    "OptimisationResultsPair",
    "SafetyFactorOptimisationResults",
    "SafetyFactorOptimisationStepResult",
    "SafetyFactorOptimisationStepResultAngle",
    "SafetyFactorOptimisationStepResultNumber",
    "SafetyFactorOptimisationStepResultShortLength",
)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3416 import (
        AbstractAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3417 import (
        AbstractShaftCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3418 import (
        AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3419 import (
        AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3420 import (
        AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3421 import (
        AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3422 import (
        AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3423 import (
        AssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3424 import (
        BearingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3425 import (
        BeltConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3426 import (
        BeltDriveCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3427 import (
        BevelDifferentialGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3428 import (
        BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3429 import (
        BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3430 import (
        BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3431 import (
        BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3432 import (
        BevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3433 import (
        BevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3434 import (
        BevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3435 import (
        BoltCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3436 import (
        BoltedJointCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3437 import (
        ClutchCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3438 import (
        ClutchConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3439 import (
        ClutchHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3440 import (
        CoaxialConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3441 import (
        ComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3442 import (
        ConceptCouplingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3443 import (
        ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3444 import (
        ConceptCouplingHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3445 import (
        ConceptGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3446 import (
        ConceptGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3447 import (
        ConceptGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3448 import (
        ConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3449 import (
        ConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3450 import (
        ConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3451 import (
        ConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3452 import (
        ConnectorCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3453 import (
        CouplingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3454 import (
        CouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3455 import (
        CouplingHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3456 import (
        CVTBeltConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3457 import (
        CVTCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3458 import (
        CVTPulleyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3459 import (
        CycloidalAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3460 import (
        CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3461 import (
        CycloidalDiscCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3462 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3463 import (
        CylindricalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3464 import (
        CylindricalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3465 import (
        CylindricalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3466 import (
        CylindricalPlanetGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3467 import (
        DatumCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3468 import (
        ExternalCADModelCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3469 import (
        FaceGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3470 import (
        FaceGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3471 import (
        FaceGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3472 import (
        FEPartCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3473 import (
        FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3474 import (
        GearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3475 import (
        GearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3476 import (
        GearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3477 import (
        GuideDxfModelCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3478 import (
        HypoidGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3479 import (
        HypoidGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3480 import (
        HypoidGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3481 import (
        InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3482 import (
        KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3483 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3484 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3485 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3486 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3487 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3488 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3489 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3490 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3491 import (
        MassDiscCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3492 import (
        MeasurementComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3493 import (
        MicrophoneArrayCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3494 import (
        MicrophoneCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3495 import (
        MountableComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3496 import (
        OilSealCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3497 import (
        PartCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3498 import (
        PartToPartShearCouplingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3499 import (
        PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3500 import (
        PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3501 import (
        PlanetaryConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3502 import (
        PlanetaryGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3503 import (
        PlanetCarrierCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3504 import (
        PointLoadCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3505 import (
        PowerLoadCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3506 import (
        PulleyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3507 import (
        RingPinsCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3508 import (
        RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3509 import (
        RollingRingAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3510 import (
        RollingRingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3511 import (
        RollingRingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3512 import (
        RootAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3513 import (
        ShaftCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3514 import (
        ShaftHubConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3515 import (
        ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3516 import (
        SpecialisedAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3517 import (
        SpiralBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3518 import (
        SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3519 import (
        SpiralBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3520 import (
        SpringDamperCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3521 import (
        SpringDamperConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3522 import (
        SpringDamperHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3523 import (
        StraightBevelDiffGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3524 import (
        StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3525 import (
        StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3526 import (
        StraightBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3527 import (
        StraightBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3528 import (
        StraightBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3529 import (
        StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3530 import (
        StraightBevelSunGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3531 import (
        SynchroniserCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3532 import (
        SynchroniserHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3533 import (
        SynchroniserPartCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3534 import (
        SynchroniserSleeveCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3535 import (
        TorqueConverterCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3536 import (
        TorqueConverterConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3537 import (
        TorqueConverterPumpCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3538 import (
        TorqueConverterTurbineCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3539 import (
        UnbalancedMassCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3540 import (
        VirtualComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3541 import (
        WormGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3542 import (
        WormGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3543 import (
        WormGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3544 import (
        ZerolBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3545 import (
        ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3546 import (
        ZerolBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3416": [
            "AbstractAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3417": [
            "AbstractShaftCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3418": [
            "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3419": [
            "AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3420": [
            "AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3421": [
            "AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3422": [
            "AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3423": [
            "AssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3424": [
            "BearingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3425": [
            "BeltConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3426": [
            "BeltDriveCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3427": [
            "BevelDifferentialGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3428": [
            "BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3429": [
            "BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3430": [
            "BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3431": [
            "BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3432": [
            "BevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3433": [
            "BevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3434": [
            "BevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3435": [
            "BoltCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3436": [
            "BoltedJointCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3437": [
            "ClutchCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3438": [
            "ClutchConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3439": [
            "ClutchHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3440": [
            "CoaxialConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3441": [
            "ComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3442": [
            "ConceptCouplingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3443": [
            "ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3444": [
            "ConceptCouplingHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3445": [
            "ConceptGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3446": [
            "ConceptGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3447": [
            "ConceptGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3448": [
            "ConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3449": [
            "ConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3450": [
            "ConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3451": [
            "ConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3452": [
            "ConnectorCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3453": [
            "CouplingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3454": [
            "CouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3455": [
            "CouplingHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3456": [
            "CVTBeltConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3457": [
            "CVTCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3458": [
            "CVTPulleyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3459": [
            "CycloidalAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3460": [
            "CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3461": [
            "CycloidalDiscCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3462": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3463": [
            "CylindricalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3464": [
            "CylindricalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3465": [
            "CylindricalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3466": [
            "CylindricalPlanetGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3467": [
            "DatumCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3468": [
            "ExternalCADModelCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3469": [
            "FaceGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3470": [
            "FaceGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3471": [
            "FaceGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3472": [
            "FEPartCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3473": [
            "FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3474": [
            "GearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3475": [
            "GearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3476": [
            "GearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3477": [
            "GuideDxfModelCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3478": [
            "HypoidGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3479": [
            "HypoidGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3480": [
            "HypoidGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3481": [
            "InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3482": [
            "KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3483": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3484": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3485": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3486": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3487": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3488": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3489": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3490": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3491": [
            "MassDiscCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3492": [
            "MeasurementComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3493": [
            "MicrophoneArrayCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3494": [
            "MicrophoneCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3495": [
            "MountableComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3496": [
            "OilSealCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3497": [
            "PartCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3498": [
            "PartToPartShearCouplingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3499": [
            "PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3500": [
            "PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3501": [
            "PlanetaryConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3502": [
            "PlanetaryGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3503": [
            "PlanetCarrierCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3504": [
            "PointLoadCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3505": [
            "PowerLoadCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3506": [
            "PulleyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3507": [
            "RingPinsCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3508": [
            "RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3509": [
            "RollingRingAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3510": [
            "RollingRingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3511": [
            "RollingRingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3512": [
            "RootAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3513": [
            "ShaftCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3514": [
            "ShaftHubConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3515": [
            "ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3516": [
            "SpecialisedAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3517": [
            "SpiralBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3518": [
            "SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3519": [
            "SpiralBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3520": [
            "SpringDamperCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3521": [
            "SpringDamperConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3522": [
            "SpringDamperHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3523": [
            "StraightBevelDiffGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3524": [
            "StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3525": [
            "StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3526": [
            "StraightBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3527": [
            "StraightBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3528": [
            "StraightBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3529": [
            "StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3530": [
            "StraightBevelSunGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3531": [
            "SynchroniserCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3532": [
            "SynchroniserHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3533": [
            "SynchroniserPartCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3534": [
            "SynchroniserSleeveCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3535": [
            "TorqueConverterCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3536": [
            "TorqueConverterConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3537": [
            "TorqueConverterPumpCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3538": [
            "TorqueConverterTurbineCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3539": [
            "UnbalancedMassCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3540": [
            "VirtualComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3541": [
            "WormGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3542": [
            "WormGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3543": [
            "WormGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3544": [
            "ZerolBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3545": [
            "ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3546": [
            "ZerolBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSteadyStateSynchronousResponse",
    "AbstractShaftCompoundSteadyStateSynchronousResponse",
    "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse",
    "AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse",
    "AssemblyCompoundSteadyStateSynchronousResponse",
    "BearingCompoundSteadyStateSynchronousResponse",
    "BeltConnectionCompoundSteadyStateSynchronousResponse",
    "BeltDriveCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse",
    "BevelGearCompoundSteadyStateSynchronousResponse",
    "BevelGearMeshCompoundSteadyStateSynchronousResponse",
    "BevelGearSetCompoundSteadyStateSynchronousResponse",
    "BoltCompoundSteadyStateSynchronousResponse",
    "BoltedJointCompoundSteadyStateSynchronousResponse",
    "ClutchCompoundSteadyStateSynchronousResponse",
    "ClutchConnectionCompoundSteadyStateSynchronousResponse",
    "ClutchHalfCompoundSteadyStateSynchronousResponse",
    "CoaxialConnectionCompoundSteadyStateSynchronousResponse",
    "ComponentCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingHalfCompoundSteadyStateSynchronousResponse",
    "ConceptGearCompoundSteadyStateSynchronousResponse",
    "ConceptGearMeshCompoundSteadyStateSynchronousResponse",
    "ConceptGearSetCompoundSteadyStateSynchronousResponse",
    "ConicalGearCompoundSteadyStateSynchronousResponse",
    "ConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "ConicalGearSetCompoundSteadyStateSynchronousResponse",
    "ConnectionCompoundSteadyStateSynchronousResponse",
    "ConnectorCompoundSteadyStateSynchronousResponse",
    "CouplingCompoundSteadyStateSynchronousResponse",
    "CouplingConnectionCompoundSteadyStateSynchronousResponse",
    "CouplingHalfCompoundSteadyStateSynchronousResponse",
    "CVTBeltConnectionCompoundSteadyStateSynchronousResponse",
    "CVTCompoundSteadyStateSynchronousResponse",
    "CVTPulleyCompoundSteadyStateSynchronousResponse",
    "CycloidalAssemblyCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse",
    "CylindricalGearCompoundSteadyStateSynchronousResponse",
    "CylindricalGearMeshCompoundSteadyStateSynchronousResponse",
    "CylindricalGearSetCompoundSteadyStateSynchronousResponse",
    "CylindricalPlanetGearCompoundSteadyStateSynchronousResponse",
    "DatumCompoundSteadyStateSynchronousResponse",
    "ExternalCADModelCompoundSteadyStateSynchronousResponse",
    "FaceGearCompoundSteadyStateSynchronousResponse",
    "FaceGearMeshCompoundSteadyStateSynchronousResponse",
    "FaceGearSetCompoundSteadyStateSynchronousResponse",
    "FEPartCompoundSteadyStateSynchronousResponse",
    "FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse",
    "GearCompoundSteadyStateSynchronousResponse",
    "GearMeshCompoundSteadyStateSynchronousResponse",
    "GearSetCompoundSteadyStateSynchronousResponse",
    "GuideDxfModelCompoundSteadyStateSynchronousResponse",
    "HypoidGearCompoundSteadyStateSynchronousResponse",
    "HypoidGearMeshCompoundSteadyStateSynchronousResponse",
    "HypoidGearSetCompoundSteadyStateSynchronousResponse",
    "InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse",
    "MassDiscCompoundSteadyStateSynchronousResponse",
    "MeasurementComponentCompoundSteadyStateSynchronousResponse",
    "MicrophoneArrayCompoundSteadyStateSynchronousResponse",
    "MicrophoneCompoundSteadyStateSynchronousResponse",
    "MountableComponentCompoundSteadyStateSynchronousResponse",
    "OilSealCompoundSteadyStateSynchronousResponse",
    "PartCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse",
    "PlanetaryConnectionCompoundSteadyStateSynchronousResponse",
    "PlanetaryGearSetCompoundSteadyStateSynchronousResponse",
    "PlanetCarrierCompoundSteadyStateSynchronousResponse",
    "PointLoadCompoundSteadyStateSynchronousResponse",
    "PowerLoadCompoundSteadyStateSynchronousResponse",
    "PulleyCompoundSteadyStateSynchronousResponse",
    "RingPinsCompoundSteadyStateSynchronousResponse",
    "RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse",
    "RollingRingAssemblyCompoundSteadyStateSynchronousResponse",
    "RollingRingCompoundSteadyStateSynchronousResponse",
    "RollingRingConnectionCompoundSteadyStateSynchronousResponse",
    "RootAssemblyCompoundSteadyStateSynchronousResponse",
    "ShaftCompoundSteadyStateSynchronousResponse",
    "ShaftHubConnectionCompoundSteadyStateSynchronousResponse",
    "ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "SpecialisedAssemblyCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearSetCompoundSteadyStateSynchronousResponse",
    "SpringDamperCompoundSteadyStateSynchronousResponse",
    "SpringDamperConnectionCompoundSteadyStateSynchronousResponse",
    "SpringDamperHalfCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearSetCompoundSteadyStateSynchronousResponse",
    "StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelSunGearCompoundSteadyStateSynchronousResponse",
    "SynchroniserCompoundSteadyStateSynchronousResponse",
    "SynchroniserHalfCompoundSteadyStateSynchronousResponse",
    "SynchroniserPartCompoundSteadyStateSynchronousResponse",
    "SynchroniserSleeveCompoundSteadyStateSynchronousResponse",
    "TorqueConverterCompoundSteadyStateSynchronousResponse",
    "TorqueConverterConnectionCompoundSteadyStateSynchronousResponse",
    "TorqueConverterPumpCompoundSteadyStateSynchronousResponse",
    "TorqueConverterTurbineCompoundSteadyStateSynchronousResponse",
    "UnbalancedMassCompoundSteadyStateSynchronousResponse",
    "VirtualComponentCompoundSteadyStateSynchronousResponse",
    "WormGearCompoundSteadyStateSynchronousResponse",
    "WormGearMeshCompoundSteadyStateSynchronousResponse",
    "WormGearSetCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearSetCompoundSteadyStateSynchronousResponse",
)
